changeset 2226:2a09a177ed5f

[gaim-migrate @ 2236] hopefully this won't break anything committer: Tailor Script <tailor@pidgin.im>
author Eric Warmenhoven <eric@warmenhoven.org>
date Thu, 06 Sep 2001 19:47:02 +0000
parents 7abd9297efac
children a93a6fe22330
files src/protocols/msn/msn.c
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/protocols/msn/msn.c	Thu Sep 06 16:54:06 2001 +0000
+++ b/src/protocols/msn/msn.c	Thu Sep 06 19:47:02 2001 +0000
@@ -947,7 +947,7 @@
 		return;
 	}
 
-	g_snprintf(buf, sizeof(buf), "USR %d MD5 I %s\n", ++md->trId, gc->username);
+	g_snprintf(buf, sizeof(buf), "VER %d MSNP5\n", ++md->trId);
 	if (msn_write(md->fd, buf, strlen(buf)) < 0) {
 		hide_login_progress(gc, "Unable to talk to Notification Server");
 		signoff(gc);
@@ -978,8 +978,8 @@
 	g_strchomp(buf);
 
 	if (!g_strncasecmp(buf, "VER", 3)) {
-		/* we got VER, check to see that MSNP2 is in the list, then send INF */
-		if (!strstr(buf, "MSNP2")) {
+		/* we got VER, check to see that MSNP5 is in the list, then send INF */
+		if (!strstr(buf, "MSNP5")) {
 			hide_login_progress(gc, "Protocol not supported");
 			signoff(gc);
 			return;
@@ -1133,7 +1133,7 @@
 		return;
 	}
 
-	g_snprintf(buf, sizeof(buf), "VER %d MSNP2\n", ++md->trId);
+	g_snprintf(buf, sizeof(buf), "VER %d MSNP5\n", ++md->trId);
 	if (msn_write(md->fd, buf, strlen(buf)) < 0) {
 		hide_login_progress(gc, "Unable to write to server");
 		signoff(gc);